@@ -21,7 +21,9 @@ from homeassistant.const import (
     CONF_NAME,
     LENGTH_KILOMETERS,
     LENGTH_METERS,
+    LENGTH_MILLIMETERS,
     PERCENTAGE,
+    PRESSURE_MBAR,
     SPEED_KILOMETERS_PER_HOUR,
     TEMP_CELSIUS,
 )
@@ -66,11 +68,11 @@ SENSOR_TYPES = {
     "gust_kt": ["Wind Gust kt", "kt"],
     "air_temp": ["Air Temp C", TEMP_CELSIUS],
     "dewpt": ["Dew Point C", TEMP_CELSIUS],
-    "press": ["Pressure mb", "mbar"],
+    "press": ["Pressure mb", PRESSURE_MBAR],
     "press_qnh": ["Pressure qnh", "qnh"],
     "press_msl": ["Pressure msl", "msl"],
     "press_tend": ["Pressure Tend", None],
-    "rain_trace": ["Rain Today", "mm"],
+    "rain_trace": ["Rain Today", LENGTH_MILLIMETERS],
     "rel_hum": ["Relative Humidity", PERCENTAGE],
     "sea_state": ["Sea State", None],
     "swell_dir_worded": ["Swell Direction", None],
