@@ -2,6 +2,7 @@
 import asyncio
 from datetime import timedelta
 import logging
+from typing import Callable, List
 
 from haffmpeg.camera import CameraMjpeg
 from haffmpeg.tools import IMAGE_JPEG, ImageFrame
@@ -9,47 +10,67 @@ import voluptuous as vol
 
 from homeassistant.components.camera import PLATFORM_SCHEMA, Camera
 from homeassistant.components.ffmpeg import DATA_FFMPEG
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.helpers import config_validation as cv
 from homeassistant.helpers.aiohttp_client import async_aiohttp_proxy_stream
+from homeassistant.helpers.entity import Entity
+from homeassistant.helpers.typing import HomeAssistantType
 from homeassistant.util import Throttle
 
-from . import DATA_CANARY, DEFAULT_TIMEOUT
+from . import CanaryData
+from .const import (
+    CONF_FFMPEG_ARGUMENTS,
+    DATA_CANARY,
+    DEFAULT_FFMPEG_ARGUMENTS,
+    DEFAULT_TIMEOUT,
+    DOMAIN,
+    MANUFACTURER,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
-CONF_FFMPEG_ARGUMENTS = "ffmpeg_arguments"
-DEFAULT_ARGUMENTS = "-pred 1"
-
 MIN_TIME_BETWEEN_SESSION_RENEW = timedelta(seconds=90)
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
-    {vol.Optional(CONF_FFMPEG_ARGUMENTS, default=DEFAULT_ARGUMENTS): cv.string}
+PLATFORM_SCHEMA = vol.All(
+    cv.deprecated(CONF_FFMPEG_ARGUMENTS, invalidation_version="0.118"),
+    PLATFORM_SCHEMA.extend(
+        {
+            vol.Optional(
+                CONF_FFMPEG_ARGUMENTS, default=DEFAULT_FFMPEG_ARGUMENTS
+            ): cv.string
+        }
+    ),
 )
 
 
-def setup_platform(hass, config, add_entities, discovery_info=None):
-    """Set up the Canary sensors."""
-    if discovery_info is not None:
-        return
+async def async_setup_entry(
+    hass: HomeAssistantType,
+    entry: ConfigEntry,
+    async_add_entities: Callable[[List[Entity], bool], None],
+) -> None:
+    """Set up Canary sensors based on a config entry."""
+    data: CanaryData = hass.data[DOMAIN][entry.entry_id][DATA_CANARY]
 
-    data = hass.data[DATA_CANARY]
-    devices = []
+    ffmpeg_arguments = entry.options.get(
+        CONF_FFMPEG_ARGUMENTS, DEFAULT_FFMPEG_ARGUMENTS
+    )
+    cameras = []
 
     for location in data.locations:
         for device in location.devices:
             if device.is_online:
-                devices.append(
+                cameras.append(
                     CanaryCamera(
                         hass,
                         data,
                         location,
                         device,
                         DEFAULT_TIMEOUT,
-                        config[CONF_FFMPEG_ARGUMENTS],
+                        ffmpeg_arguments,
                     )
                 )
 
-    add_entities(devices, True)
+    async_add_entities(cameras, True)
 
 
 class CanaryCamera(Camera):
@@ -64,13 +85,31 @@ class CanaryCamera(Camera):
         self._data = data
         self._location = location
         self._device = device
+        self._device_id = device.device_id
+        self._device_name = device.name
+        self._device_type_name = device.device_type["name"]
         self._timeout = timeout
         self._live_stream_session = None
 
     @property
     def name(self):
         """Return the name of this device."""
-        return self._device.name
+        return self._device_name
+
+    @property
+    def unique_id(self):
+        """Return the unique ID of this camera."""
+        return str(self._device_id)
+
+    @property
+    def device_info(self):
+        """Return the device_info of the device."""
+        return {
+            "identifiers": {(DOMAIN, str(self._device_id))},
+            "name": self._device_name,
+            "model": self._device_type_name,
+            "manufacturer": MANUFACTURER,
+        }
 
     @property
     def is_recording(self):
