@@ -41,7 +41,20 @@ async def async_setup_entry(
                     element_uid=binary_sensor,
                 )
             )
-
+    for device in hass.data[DOMAIN]["homecontrol"].devices.values():
+        if hasattr(device, "remote_control_property"):
+            for remote in device.remote_control_property:
+                for index in range(
+                    1, device.remote_control_property[remote].key_count + 1
+                ):
+                    entities.append(
+                        DevoloRemoteControl(
+                            homecontrol=hass.data[DOMAIN]["homecontrol"],
+                            device_instance=device,
+                            element_uid=remote,
+                            key=index,
+                        )
+                    )
     async_add_entities(entities, False)
 
 
@@ -54,46 +67,70 @@ class DevoloBinaryDeviceEntity(DevoloDeviceEntity, BinarySensorEntity):
             element_uid
         )
 
-        self._device_class = DEVICE_CLASS_MAPPING.get(
-            self._binary_sensor_property.sub_type
-            or self._binary_sensor_property.sensor_type
-        )
-        name = device_instance.itemName
-
-        if self._device_class is None:
-            if device_instance.binary_sensor_property.get(element_uid).sub_type != "":
-                name += f" {device_instance.binary_sensor_property.get(element_uid).sub_type}"
-            else:
-                name += f" {device_instance.binary_sensor_property.get(element_uid).sensor_type}"
-
         super().__init__(
             homecontrol=homecontrol,
             device_instance=device_instance,
             element_uid=element_uid,
-            name=name,
-            sync=self._sync,
         )
 
-        self._state = self._binary_sensor_property.state
+        self._device_class = DEVICE_CLASS_MAPPING.get(
+            self._binary_sensor_property.sub_type
+            or self._binary_sensor_property.sensor_type
+        )
 
-        self._subscriber = None
+        if self._device_class is None:
+            if device_instance.binary_sensor_property.get(element_uid).sub_type != "":
+                self._name += f" {device_instance.binary_sensor_property.get(element_uid).sub_type}"
+            else:
+                self._name += f" {device_instance.binary_sensor_property.get(element_uid).sensor_type}"
+
+        self._value = self._binary_sensor_property.state
 
     @property
     def is_on(self):
         """Return the state."""
-        return self._state
+        return self._value
 
     @property
     def device_class(self):
         """Return device class."""
         return self._device_class
 
-    def _sync(self, message=None):
+
+class DevoloRemoteControl(DevoloDeviceEntity, BinarySensorEntity):
+    """Representation of a remote control within devolo Home Control."""
+
+    def __init__(self, homecontrol, device_instance, element_uid, key):
+        """Initialize a devolo remote control."""
+        self._remote_control_property = device_instance.remote_control_property.get(
+            element_uid
+        )
+
+        super().__init__(
+            homecontrol=homecontrol,
+            device_instance=device_instance,
+            element_uid=f"{element_uid}_{key}",
+        )
+
+        self._key = key
+        self._state = False
+
+    @property
+    def is_on(self):
+        """Return the state."""
+        return self._state
+
+    def _sync(self, message):
         """Update the binary sensor state."""
-        if message[0].startswith("devolo.BinarySensor"):
-            self._state = self._device_instance.binary_sensor_property[message[0]].state
-        elif message[0].startswith("hdm"):
-            self._available = self._device_instance.is_online()
+        if (
+            message[0] == self._remote_control_property.element_uid
+            and message[1] == self._key
+        ):
+            self._state = True
+        elif (
+            message[0] == self._remote_control_property.element_uid and message[1] == 0
+        ):
+            self._state = False
         else:
-            _LOGGER.debug("No valid message received: %s", message)
+            self._generic_message(message)
         self.schedule_update_ha_state()
