@@ -7,6 +7,7 @@ from homeassistant.const import (
     DEVICE_CLASS_HUMIDITY,
     DEVICE_CLASS_ILLUMINANCE,
     DEVICE_CLASS_TEMPERATURE,
+    LIGHT_LUX,
     PERCENTAGE,
     TEMP_CELSIUS,
     TEMP_FAHRENHEIT,
@@ -35,7 +36,7 @@ SENSOR_TYPES = {
         None,
         DEVICE_CLASS_HUMIDITY,
     ],
-    "com.fibaro.lightSensor": ["Light", "lx", None, DEVICE_CLASS_ILLUMINANCE],
+    "com.fibaro.lightSensor": ["Light", LIGHT_LUX, None, DEVICE_CLASS_ILLUMINANCE],
 }
 
 _LOGGER = logging.getLogger(__name__)
@@ -71,7 +72,7 @@ class FibaroSensor(FibaroDevice, Entity):
         try:
             if not self._unit:
                 if self.fibaro_device.properties.unit == "lux":
-                    self._unit = "lx"
+                    self._unit = LIGHT_LUX
                 elif self.fibaro_device.properties.unit == "C":
                     self._unit = TEMP_CELSIUS
                 elif self.fibaro_device.properties.unit == "F":
