@@ -8,7 +8,6 @@ from aiohttp.hdrs import REFERER, USER_AGENT
 import async_timeout
 from gtts_token import gtts_token
 import voluptuous as vol
-import yarl
 
 from homeassistant.components.tts import CONF_LANG, PLATFORM_SCHEMA, Provider
 from homeassistant.const import HTTP_OK
@@ -129,7 +128,7 @@ class GoogleProvider(Provider):
             url_param = {
                 "ie": "UTF-8",
                 "tl": language,
-                "q": yarl.URL(part).raw_path,
+                "q": part,
                 "tk": part_token,
                 "total": len(message_parts),
                 "idx": idx,
