@@ -63,6 +63,7 @@ from .const import (
     KEY_DEVICE_INFORMATION,
     KEY_DEVICE_SIGNAL,
     KEY_DIALUP_MOBILE_DATASWITCH,
+    KEY_MONITORING_CHECK_NOTIFICATIONS,
     KEY_MONITORING_MONTH_STATISTICS,
     KEY_MONITORING_STATUS,
     KEY_MONITORING_TRAFFIC_STATISTICS,
@@ -243,6 +244,10 @@ class Router:
         self._get_data(
             KEY_MONITORING_MONTH_STATISTICS, self.client.monitoring.month_statistics
         )
+        self._get_data(
+            KEY_MONITORING_CHECK_NOTIFICATIONS,
+            self.client.monitoring.check_notifications,
+        )
         self._get_data(KEY_MONITORING_STATUS, self.client.monitoring.status)
         self._get_data(
             KEY_MONITORING_TRAFFIC_STATISTICS, self.client.monitoring.traffic_statistics
