@@ -128,9 +128,9 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry):
             shade_data = _async_map_data_by_id(
                 (await shades.get_resources())[SHADE_DATA]
             )
-    except HUB_EXCEPTIONS:
+    except HUB_EXCEPTIONS as err:
         _LOGGER.error("Connection error to PowerView hub: %s", hub_address)
-        raise ConfigEntryNotReady
+        raise ConfigEntryNotReady from err
 
     if not device_info:
         _LOGGER.error("Unable to initialize PowerView hub: %s", hub_address)
