@@ -107,12 +107,9 @@ class ImageProcessingEntity(Entity):
         """Process image."""
         raise NotImplementedError()
 
-    def async_process_image(self, image):
-        """Process image.
-
-        This method must be run in the event loop and returns a coroutine.
-        """
-        return self.hass.async_add_job(self.process_image, image)
+    async def async_process_image(self, image):
+        """Process image."""
+        return await self.hass.async_add_job(self.process_image, image)
 
     async def async_update(self):
         """Update image and process it.
