@@ -44,7 +44,10 @@ from homeassistant.components.lock import DOMAIN as LOCK
 from homeassistant.components.sensor import DOMAIN as SENSOR
 from homeassistant.components.switch import DOMAIN as SWITCH
 from homeassistant.const import (
+    AREA_SQUARE_METERS,
     CONCENTRATION_PARTS_PER_MILLION,
+    CURRENCY_CENT,
+    CURRENCY_DOLLAR,
     DEGREE,
     ENERGY_KILO_WATT_HOUR,
     FREQUENCY_HERTZ,
@@ -54,11 +57,15 @@ from homeassistant.const import (
     LENGTH_KILOMETERS,
     LENGTH_METERS,
     LENGTH_MILES,
+    LENGTH_MILLIMETERS,
+    LIGHT_LUX,
     MASS_KILOGRAMS,
     MASS_POUNDS,
     PERCENTAGE,
     POWER_WATT,
+    PRESSURE_HPA,
     PRESSURE_INHG,
+    PRESSURE_MBAR,
     SERVICE_LOCK,
     SERVICE_UNLOCK,
     SPEED_KILOMETERS_PER_HOUR,
@@ -86,6 +93,8 @@ from homeassistant.const import (
     TIME_YEARS,
     UV_INDEX,
     VOLT,
+    VOLUME_CUBIC_FEET,
+    VOLUME_CUBIC_METERS,
     VOLUME_GALLONS,
     VOLUME_LITERS,
 )
@@ -316,9 +325,9 @@ UOM_FRIENDLY_NAME = {
     "3": f"btu/{TIME_HOURS}",
     "4": TEMP_CELSIUS,
     "5": LENGTH_CENTIMETERS,
-    "6": f"{LENGTH_FEET}³",
-    "7": f"{LENGTH_FEET}³/{TIME_MINUTES}",
-    "8": "m³",
+    "6": VOLUME_CUBIC_FEET,
+    "7": f"{VOLUME_CUBIC_FEET}/{TIME_MINUTES}",
+    "8": f"{VOLUME_CUBIC_METERS}",
     "9": TIME_DAYS,
     "10": TIME_DAYS,
     "12": "dB",
@@ -344,17 +353,17 @@ UOM_FRIENDLY_NAME = {
     "33": ENERGY_KILO_WATT_HOUR,
     "34": "liedu",
     "35": VOLUME_LITERS,
-    "36": "lx",
+    "36": LIGHT_LUX,
     "37": "mercalli",
     "38": LENGTH_METERS,
-    "39": f"{LENGTH_METERS}³/{TIME_HOURS}",
+    "39": f"{VOLUME_CUBIC_METERS}/{TIME_HOURS}",
     "40": SPEED_METERS_PER_SECOND,
     "41": "mA",
     "42": TIME_MILLISECONDS,
     "43": "mV",
     "44": TIME_MINUTES,
     "45": TIME_MINUTES,
-    "46": f"mm/{TIME_HOURS}",
+    "46": f"{LENGTH_MILLIMETERS}/{TIME_HOURS}",
     "47": TIME_MONTHS,
     "48": SPEED_MILES_PER_HOUR,
     "49": SPEED_METERS_PER_SECOND,
@@ -377,15 +386,15 @@ UOM_FRIENDLY_NAME = {
     "71": UV_INDEX,
     "72": VOLT,
     "73": POWER_WATT,
-    "74": f"{POWER_WATT}/{LENGTH_METERS}²",
+    "74": f"{POWER_WATT}/{AREA_SQUARE_METERS}",
     "75": "weekday",
     "76": DEGREE,
     "77": TIME_YEARS,
-    "82": "mm",
+    "82": LENGTH_MILLIMETERS,
     "83": LENGTH_KILOMETERS,
     "85": "Ω",
     "86": "kΩ",
-    "87": f"{LENGTH_METERS}³/{LENGTH_METERS}³",
+    "87": f"{VOLUME_CUBIC_METERS}/{VOLUME_CUBIC_METERS}",
     "88": "Water activity",
     "89": "RPM",
     "90": FREQUENCY_HERTZ,
@@ -394,10 +403,10 @@ UOM_FRIENDLY_NAME = {
     UOM_8_BIT_RANGE: "",  # Range 0-255, no unit.
     UOM_DOUBLE_TEMP: UOM_DOUBLE_TEMP,
     "102": "kWs",
-    "103": "$",
-    "104": "¢",
+    "103": CURRENCY_DOLLAR,
+    "104": CURRENCY_CENT,
     "105": LENGTH_INCHES,
-    "106": f"mm/{TIME_DAYS}",
+    "106": f"{LENGTH_MILLIMETERS}/{TIME_DAYS}",
     "107": "",  # raw 1-byte unsigned value
     "108": "",  # raw 2-byte unsigned value
     "109": "",  # raw 3-byte unsigned value
@@ -407,8 +416,8 @@ UOM_FRIENDLY_NAME = {
     "113": "",  # raw 3-byte signed value
     "114": "",  # raw 4-byte signed value
     "116": LENGTH_MILES,
-    "117": "mbar",
-    "118": "hPa",
+    "117": PRESSURE_MBAR,
+    "118": PRESSURE_HPA,
     "119": f"{POWER_WATT}{TIME_HOURS}",
     "120": f"{LENGTH_INCHES}/{TIME_DAYS}",
 }
