@@ -4,7 +4,7 @@ import logging
 
 import lupupy.constants as CONST
 
-from homeassistant.components.binary_sensor import DEVICE_CLASSES, BinarySensorDevice
+from homeassistant.components.binary_sensor import DEVICE_CLASSES, BinarySensorEntity
 
 from . import DOMAIN as LUPUSEC_DOMAIN, LupusecDevice
 
@@ -29,7 +29,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     add_entities(devices)
 
 
-class LupusecBinarySensor(LupusecDevice, BinarySensorDevice):
+class LupusecBinarySensor(LupusecDevice, BinarySensorEntity):
     """A binary sensor implementation for Lupusec device."""
 
     @property
