@@ -3,6 +3,7 @@ import asyncio
 import json
 import logging
 import re
+import time
 
 from homeassistant.components import mqtt
 from homeassistant.const import CONF_DEVICE, CONF_PLATFORM
@@ -31,6 +32,7 @@ SUPPORTED_COMPONENTS = [
     "lock",
     "sensor",
     "switch",
+    "tag",
     "vacuum",
 ]
 
@@ -40,6 +42,7 @@ DATA_CONFIG_ENTRY_LOCK = "mqtt_config_entry_lock"
 DISCOVERY_UNSUBSCRIBE = "mqtt_discovery_unsubscribe"
 MQTT_DISCOVERY_UPDATED = "mqtt_discovery_updated_{}"
 MQTT_DISCOVERY_NEW = "mqtt_discovery_new_{}_{}"
+LAST_DISCOVERY = "mqtt_last_discovery"
 
 TOPIC_BASE = "~"
 
@@ -65,6 +68,7 @@ async def async_start(
 
     async def async_device_message_received(msg):
         """Process the received message."""
+        hass.data[LAST_DISCOVERY] = time.time()
         payload = msg.payload
         topic = msg.topic
         topic_trimmed = topic.replace(f"{discovery_topic}/", "", 1)
@@ -151,6 +155,12 @@ async def async_start(
                         from . import device_automation
 
                         await device_automation.async_setup_entry(hass, config_entry)
+                    elif component == "tag":
+                        # Local import to avoid circular dependencies
+                        # pylint: disable=import-outside-toplevel
+                        from . import tag
+
+                        await tag.async_setup_entry(hass, config_entry)
                     else:
                         await hass.config_entries.async_forward_entry_setup(
                             config_entry, component
@@ -167,6 +177,7 @@ async def async_start(
     hass.data[DISCOVERY_UNSUBSCRIBE] = await mqtt.async_subscribe(
         hass, f"{discovery_topic}/#", async_device_message_received, 0
     )
+    hass.data[LAST_DISCOVERY] = time.time()
 
     return True
 
