@@ -16,7 +16,7 @@ from homeassistant.components.light import (
     SUPPORT_COLOR_TEMP,
     SUPPORT_EFFECT,
     SUPPORT_TRANSITION,
-    Light,
+    LightEntity,
 )
 from homeassistant.const import CONF_HOST, CONF_NAME, CONF_TOKEN
 import homeassistant.helpers.config_validation as cv
@@ -57,7 +57,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     """Set up the Nanoleaf light."""
 
     if DATA_NANOLEAF not in hass.data:
-        hass.data[DATA_NANOLEAF] = dict()
+        hass.data[DATA_NANOLEAF] = {}
 
     token = ""
     if discovery_info is not None:
@@ -103,7 +103,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     add_entities([NanoleafLight(nanoleaf_light, name)], True)
 
 
-class NanoleafLight(Light):
+class NanoleafLight(LightEntity):
     """Representation of a Nanoleaf Light."""
 
     def __init__(self, light, name):
@@ -210,6 +210,10 @@ class NanoleafLight(Light):
                 self._light.brightness = int(brightness / 2.55)
 
         if effect:
+            if effect not in self._effects_list:
+                raise ValueError(
+                    f"Attempting to apply effect not in the effect list: '{effect}'"
+                )
             self._light.effect = effect
 
     def turn_off(self, **kwargs):
@@ -226,10 +230,19 @@ class NanoleafLight(Light):
         try:
             self._available = self._light.available
             self._brightness = self._light.brightness
-            self._color_temp = self._light.color_temperature
-            self._effect = self._light.effect
             self._effects_list = self._light.effects
-            self._hs_color = self._light.hue, self._light.saturation
+            # Nanoleaf api returns non-existent effect named "*Solid*" when light set to solid color.
+            # This causes various issues with scening (see https://github.com/home-assistant/core/issues/36359).
+            # Until fixed at the library level, we should ensure the effect exists before saving to light properties
+            self._effect = (
+                self._light.effect if self._light.effect in self._effects_list else None
+            )
+            if self._effect is None:
+                self._color_temp = self._light.color_temperature
+                self._hs_color = self._light.hue, self._light.saturation
+            else:
+                self._color_temp = None
+                self._hs_color = None
             self._state = self._light.on
         except Unavailable as err:
             _LOGGER.error("Could not update status for %s (%s)", self.name, err)
