@@ -1,7 +1,7 @@
 """Support for Netgear LTE binary sensors."""
 import logging
 
-from homeassistant.components.binary_sensor import DOMAIN, BinarySensorDevice
+from homeassistant.components.binary_sensor import DOMAIN, BinarySensorEntity
 from homeassistant.exceptions import PlatformNotReady
 
 from . import CONF_MONITORED_CONDITIONS, DATA_KEY, LTEEntity
@@ -30,7 +30,7 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info)
     async_add_entities(binary_sensors)
 
 
-class LTEBinarySensor(LTEEntity, BinarySensorDevice):
+class LTEBinarySensor(LTEEntity, BinarySensorEntity):
     """Netgear LTE binary sensor entity."""
 
     @property
