@@ -1,7 +1,7 @@
 """Battery Charge and Range Support for the Nissan Leaf."""
 import logging
 
-from homeassistant.const import DEVICE_CLASS_BATTERY, UNIT_PERCENTAGE
+from homeassistant.const import DEVICE_CLASS_BATTERY, PERCENTAGE
 from homeassistant.helpers.icon import icon_for_battery_level
 from homeassistant.util.distance import LENGTH_KILOMETERS, LENGTH_MILES
 from homeassistant.util.unit_system import IMPERIAL_SYSTEM, METRIC_SYSTEM
@@ -41,7 +41,7 @@ class LeafBatterySensor(LeafEntity):
     @property
     def name(self):
         """Sensor Name."""
-        return self.car.leaf.nickname + " Charge"
+        return f"{self.car.leaf.nickname} Charge"
 
     @property
     def device_class(self):
@@ -56,7 +56,7 @@ class LeafBatterySensor(LeafEntity):
     @property
     def unit_of_measurement(self):
         """Battery state measured in percentage."""
-        return UNIT_PERCENTAGE
+        return PERCENTAGE
 
     @property
     def icon(self):
@@ -77,8 +77,8 @@ class LeafRangeSensor(LeafEntity):
     def name(self):
         """Update sensor name depending on AC."""
         if self._ac_on is True:
-            return self.car.leaf.nickname + " Range (AC)"
-        return self.car.leaf.nickname + " Range"
+            return f"{self.car.leaf.nickname} Range (AC)"
+        return f"{self.car.leaf.nickname} Range"
 
     def log_registration(self):
         """Log registration."""
