@@ -7,6 +7,7 @@ from homeassistant.const import (
     DEVICE_CLASS_PRESSURE,
     DEVICE_CLASS_TEMPERATURE,
     PERCENTAGE,
+    PRESSURE_HPA,
     TEMP_CELSIUS,
 )
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -21,7 +22,7 @@ DEVICE_CLASS_SOUND = "sound_level"
 
 SENSOR_TYPES = {
     DEVICE_CLASS_TEMPERATURE: (None, 1, TEMP_CELSIUS),
-    DEVICE_CLASS_PRESSURE: (None, 0, "hPa"),
+    DEVICE_CLASS_PRESSURE: (None, 0, PRESSURE_HPA),
     DEVICE_CLASS_HUMIDITY: (None, 1, PERCENTAGE),
     DEVICE_CLASS_SOUND: ("mdi:ear-hearing", 1, "dBa"),
 }
