@@ -2,9 +2,11 @@
 from datetime import timedelta
 import functools as ft
 import logging
+from typing import Any, Iterable, cast
 
 import voluptuous as vol
 
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
     SERVICE_TOGGLE,
     SERVICE_TURN_OFF,
@@ -19,9 +21,10 @@ from homeassistant.helpers.config_validation import (  # noqa: F401
 )
 from homeassistant.helpers.entity import ToggleEntity
 from homeassistant.helpers.entity_component import EntityComponent
+from homeassistant.helpers.typing import ConfigType, HomeAssistantType
 from homeassistant.loader import bind_hass
 
-# mypy: allow-untyped-defs, no-check-untyped-defs
+# mypy: allow-untyped-calls, allow-untyped-defs, no-check-untyped-defs
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -57,14 +60,16 @@ REMOTE_SERVICE_ACTIVITY_SCHEMA = make_entity_service_schema(
 
 
 @bind_hass
-def is_on(hass, entity_id):
+def is_on(hass: HomeAssistantType, entity_id: str) -> bool:
     """Return if the remote is on based on the statemachine."""
     return hass.states.is_state(entity_id, STATE_ON)
 
 
-async def async_setup(hass, config):
+async def async_setup(hass: HomeAssistantType, config: ConfigType) -> bool:
     """Track states and offer events for remotes."""
-    component = EntityComponent(_LOGGER, DOMAIN, hass, SCAN_INTERVAL)
+    component = hass.data[DOMAIN] = EntityComponent(
+        _LOGGER, DOMAIN, hass, SCAN_INTERVAL
+    )
     await component.async_setup(config)
 
     component.async_register_entity_service(
@@ -107,28 +112,52 @@ async def async_setup(hass, config):
     return True
 
 
-class RemoteDevice(ToggleEntity):
+async def async_setup_entry(hass: HomeAssistantType, entry: ConfigEntry) -> bool:
+    """Set up a config entry."""
+    return await cast(EntityComponent, hass.data[DOMAIN]).async_setup_entry(entry)
+
+
+async def async_unload_entry(hass: HomeAssistantType, entry: ConfigEntry) -> bool:
+    """Unload a config entry."""
+    return await cast(EntityComponent, hass.data[DOMAIN]).async_unload_entry(entry)
+
+
+class RemoteEntity(ToggleEntity):
     """Representation of a remote."""
 
     @property
-    def supported_features(self):
+    def supported_features(self) -> int:
         """Flag supported features."""
         return 0
 
-    def send_command(self, command, **kwargs):
-        """Send a command to a device."""
+    def send_command(self, command: Iterable[str], **kwargs: Any) -> None:
+        """Send commands to a device."""
         raise NotImplementedError()
 
-    async def async_send_command(self, command, **kwargs):
-        """Send a command to a device."""
+    async def async_send_command(self, command: Iterable[str], **kwargs: Any) -> None:
+        """Send commands to a device."""
+        assert self.hass is not None
         await self.hass.async_add_executor_job(
             ft.partial(self.send_command, command, **kwargs)
         )
 
-    def learn_command(self, **kwargs):
+    def learn_command(self, **kwargs: Any) -> None:
         """Learn a command from a device."""
         raise NotImplementedError()
 
-    async def async_learn_command(self, **kwargs):
+    async def async_learn_command(self, **kwargs: Any) -> None:
         """Learn a command from a device."""
+        assert self.hass is not None
         await self.hass.async_add_executor_job(ft.partial(self.learn_command, **kwargs))
+
+
+class RemoteDevice(RemoteEntity):
+    """Representation of a remote (for backwards compatibility)."""
+
+    def __init_subclass__(cls, **kwargs):
+        """Print deprecation warning."""
+        super().__init_subclass__(**kwargs)
+        _LOGGER.warning(
+            "RemoteDevice is deprecated, modify %s to extend RemoteEntity",
+            cls.__name__,
+        )
