@@ -5,11 +5,18 @@ from datetime import timedelta
 DOMAIN = "smappee"
 DATA_CLIENT = "smappee_data"
 
-BASE = "BASE"
+CONF_HOSTNAME = "hostname"
+CONF_SERIALNUMBER = "serialnumber"
+CONF_TITLE = "title"
+
+ENV_CLOUD = "cloud"
+ENV_LOCAL = "local"
 
 SMAPPEE_PLATFORMS = ["binary_sensor", "sensor", "switch"]
 
-MIN_TIME_BETWEEN_UPDATES = timedelta(seconds=5)
+SUPPORTED_LOCAL_DEVICES = ("Smappee1", "Smappee2")
+
+MIN_TIME_BETWEEN_UPDATES = timedelta(seconds=20)
 
 AUTHORIZE_URL = {
     "PRODUCTION": "https://app1pub.smappee.net/dev/v1/oauth2/authorize",
