@@ -125,8 +125,8 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
         # (The model_dir is created during the manual setup process. See integration docs.)
 
         # pylint: disable=import-outside-toplevel
-        from object_detection.utils import config_util, label_map_util
         from object_detection.builders import model_builder
+        from object_detection.utils import config_util, label_map_util
     except ImportError:
         _LOGGER.error(
             "No TensorFlow Object Detection library found! Install or compile "
@@ -204,7 +204,12 @@ class TensorFlowImageProcessor(ImageProcessingEntity):
     """Representation of an TensorFlow image processor."""
 
     def __init__(
-        self, hass, camera_entity, name, category_index, config,
+        self,
+        hass,
+        camera_entity,
+        name,
+        category_index,
+        config,
     ):
         """Initialize the TensorFlow entity."""
         model_config = config.get(CONF_MODEL)
@@ -323,6 +328,8 @@ class TensorFlowImageProcessor(ImageProcessingEntity):
 
         for path in paths:
             _LOGGER.info("Saving results image to %s", path)
+            if not os.path.exists(os.path.dirname(path)):
+                os.makedirs(os.path.dirname(path), exist_ok=True)
             img.save(path)
 
     def process_image(self, image):
