@@ -1,10 +1,11 @@
 """Support for bandwidth sensors with UniFi clients."""
 import logging
 
-from homeassistant.components.sensor import DOMAIN
+from homeassistant.components.sensor import DEVICE_CLASS_TIMESTAMP, DOMAIN
 from homeassistant.const import DATA_MEGABYTES
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
+import homeassistant.util.dt as dt_util
 
 from .const import DOMAIN as UNIFI_DOMAIN
 from .unifi_client import UniFiClient
@@ -13,6 +14,7 @@ LOGGER = logging.getLogger(__name__)
 
 RX_SENSOR = "rx"
 TX_SENSOR = "tx"
+UPTIME_SENSOR = "uptime"
 
 
 async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
@@ -22,7 +24,11 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
 async def async_setup_entry(hass, config_entry, async_add_entities):
     """Set up sensors for UniFi integration."""
     controller = hass.data[UNIFI_DOMAIN][config_entry.entry_id]
-    controller.entities[DOMAIN] = {RX_SENSOR: set(), TX_SENSOR: set()}
+    controller.entities[DOMAIN] = {
+        RX_SENSOR: set(),
+        TX_SENSOR: set(),
+        UPTIME_SENSOR: set(),
+    }
 
     @callback
     def items_added(
@@ -30,7 +36,10 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     ) -> None:
         """Update the values of the controller."""
         if controller.option_allow_bandwidth_sensors:
-            add_entities(controller, async_add_entities, clients)
+            add_bandwith_entities(controller, async_add_entities, clients)
+
+        if controller.option_allow_uptime_sensors:
+            add_uptime_entities(controller, async_add_entities, clients)
 
     for signal in (controller.signal_update, controller.signal_options_update):
         controller.listeners.append(async_dispatcher_connect(hass, signal, items_added))
@@ -39,7 +48,7 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
 
 
 @callback
-def add_entities(controller, async_add_entities, clients):
+def add_bandwith_entities(controller, async_add_entities, clients):
     """Add new sensor entities from the controller."""
     sensors = []
 
@@ -55,6 +64,22 @@ def add_entities(controller, async_add_entities, clients):
         async_add_entities(sensors)
 
 
+@callback
+def add_uptime_entities(controller, async_add_entities, clients):
+    """Add new sensor entities from the controller."""
+    sensors = []
+
+    for mac in clients:
+        if mac in controller.entities[DOMAIN][UniFiUpTimeSensor.TYPE]:
+            continue
+
+        client = controller.api.clients[mac]
+        sensors.append(UniFiUpTimeSensor(client, controller))
+
+    if sensors:
+        async_add_entities(sensors)
+
+
 class UniFiBandwidthSensor(UniFiClient):
     """UniFi bandwidth sensor base class."""
 
@@ -100,3 +125,30 @@ class UniFiTxBandwidthSensor(UniFiBandwidthSensor):
         if self._is_wired:
             return self.client.wired_tx_bytes / 1000000
         return self.client.tx_bytes / 1000000
+
+
+class UniFiUpTimeSensor(UniFiClient):
+    """UniFi uptime sensor."""
+
+    DOMAIN = DOMAIN
+    TYPE = UPTIME_SENSOR
+
+    @property
+    def device_class(self) -> str:
+        """Return device class."""
+        return DEVICE_CLASS_TIMESTAMP
+
+    @property
+    def name(self) -> str:
+        """Return the name of the client."""
+        return f"{super().name} {self.TYPE.capitalize()}"
+
+    @property
+    def state(self) -> int:
+        """Return the uptime of the client."""
+        return dt_util.utc_from_timestamp(float(self.client.uptime)).isoformat()
+
+    async def options_updated(self) -> None:
+        """Config entry options are updated, remove entity if option is disabled."""
+        if not self.controller.option_allow_uptime_sensors:
+            await self.remove_item({self.client.mac})
