@@ -1,14 +1,15 @@
 """Vizio SmartCast Device support."""
 from datetime import timedelta
 import logging
-from typing import Any, Callable, Dict, List, Optional
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from pyvizio import VizioAsync
 from pyvizio.api.apps import find_app_name
-from pyvizio.const import APP_HOME, APPS, INPUT_APPS, NO_APP_RUNNING, UNKNOWN_APP
+from pyvizio.const import APP_HOME, INPUT_APPS, NO_APP_RUNNING, UNKNOWN_APP
 
 from homeassistant.components.media_player import (
     DEVICE_CLASS_SPEAKER,
+    DEVICE_CLASS_TV,
     SUPPORT_SELECT_SOUND_MODE,
     MediaPlayerEntity,
 )
@@ -23,7 +24,9 @@ from homeassistant.const import (
     STATE_OFF,
     STATE_ON,
 )
+from homeassistant.core import callback
 from homeassistant.exceptions import PlatformNotReady
+from homeassistant.helpers import entity_platform
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 from homeassistant.helpers.dispatcher import (
     async_dispatcher_connect,
@@ -31,6 +34,7 @@ from homeassistant.helpers.dispatcher import (
 )
 from homeassistant.helpers.entity import Entity
 from homeassistant.helpers.typing import HomeAssistantType
+from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
 
 from .const import (
     CONF_ADDITIONAL_CONFIGS,
@@ -41,16 +45,20 @@ from .const import (
     DEVICE_ID,
     DOMAIN,
     ICON,
+    SERVICE_UPDATE_SETTING,
     SUPPORTED_COMMANDS,
+    UPDATE_SETTING_SCHEMA,
     VIZIO_AUDIO_SETTINGS,
     VIZIO_DEVICE_CLASSES,
+    VIZIO_MUTE,
     VIZIO_MUTE_ON,
     VIZIO_SOUND_MODE,
+    VIZIO_VOLUME,
 )
 
 _LOGGER = logging.getLogger(__name__)
 
-SCAN_INTERVAL = timedelta(seconds=10)
+SCAN_INTERVAL = timedelta(seconds=30)
 PARALLEL_UPDATES = 0
 
 
@@ -73,6 +81,7 @@ async def async_setup_entry(
     params = {}
     if not config_entry.options:
         params["options"] = {CONF_VOLUME_STEP: volume_step}
+
         include_or_exclude_key = next(
             (
                 key
@@ -110,9 +119,15 @@ async def async_setup_entry(
         _LOGGER.warning("Failed to connect to %s", host)
         raise PlatformNotReady
 
-    entity = VizioDevice(config_entry, device, name, device_class,)
+    apps_coordinator = hass.data[DOMAIN].get(CONF_APPS)
+
+    entity = VizioDevice(config_entry, device, name, device_class, apps_coordinator)
 
     async_add_entities([entity], update_before_add=True)
+    platform = entity_platform.current_platform.get()
+    platform.async_register_entity_service(
+        SERVICE_UPDATE_SETTING, UPDATE_SETTING_SCHEMA, "async_update_setting"
+    )
 
 
 class VizioDevice(MediaPlayerEntity):
@@ -124,10 +139,11 @@ class VizioDevice(MediaPlayerEntity):
         device: VizioAsync,
         name: str,
         device_class: str,
+        apps_coordinator: DataUpdateCoordinator,
     ) -> None:
         """Initialize Vizio device."""
         self._config_entry = config_entry
-        self._async_unsub_listeners = []
+        self._apps_coordinator = apps_coordinator
 
         self._name = name
         self._state = None
@@ -141,6 +157,7 @@ class VizioDevice(MediaPlayerEntity):
         self._available_sound_modes = []
         self._available_inputs = []
         self._available_apps = []
+        self._all_apps = apps_coordinator.data if apps_coordinator else None
         self._conf_apps = config_entry.options.get(CONF_APPS, {})
         self._additional_app_configs = config_entry.data.get(CONF_APPS, {}).get(
             CONF_ADDITIONAL_CONFIGS, []
@@ -203,10 +220,13 @@ class VizioDevice(MediaPlayerEntity):
         audio_settings = await self._device.get_all_settings(
             VIZIO_AUDIO_SETTINGS, log_api_exception=False
         )
+
         if audio_settings:
-            self._volume_level = float(audio_settings["volume"]) / self._max_volume
-            if "mute" in audio_settings:
-                self._is_volume_muted = audio_settings["mute"].lower() == VIZIO_MUTE_ON
+            self._volume_level = float(audio_settings[VIZIO_VOLUME]) / self._max_volume
+            if VIZIO_MUTE in audio_settings:
+                self._is_volume_muted = (
+                    audio_settings[VIZIO_MUTE].lower() == VIZIO_MUTE_ON
+                )
             else:
                 self._is_volume_muted = None
 
@@ -214,8 +234,10 @@ class VizioDevice(MediaPlayerEntity):
                 self._supported_commands |= SUPPORT_SELECT_SOUND_MODE
                 self._current_sound_mode = audio_settings[VIZIO_SOUND_MODE]
                 if not self._available_sound_modes:
-                    self._available_sound_modes = await self._device.get_setting_options(
-                        VIZIO_AUDIO_SETTINGS, VIZIO_SOUND_MODE
+                    self._available_sound_modes = (
+                        await self._device.get_setting_options(
+                            VIZIO_AUDIO_SETTINGS, VIZIO_SOUND_MODE
+                        )
                     )
             else:
                 # Explicitly remove SUPPORT_SELECT_SOUND_MODE from supported features
@@ -241,14 +263,15 @@ class VizioDevice(MediaPlayerEntity):
 
         # Create list of available known apps from known app list after
         # filtering by CONF_INCLUDE/CONF_EXCLUDE
-        self._available_apps = self._apps_list(self._device.get_apps_list())
+        self._available_apps = self._apps_list([app["name"] for app in self._all_apps])
 
         self._current_app_config = await self._device.get_current_app_config(
             log_api_exception=False
         )
 
         self._current_app = find_app_name(
-            self._current_app_config, [APP_HOME, *APPS, *self._additional_app_configs]
+            self._current_app_config,
+            [APP_HOME, *self._all_apps, *self._additional_app_configs],
         )
 
         if self._current_app == NO_APP_RUNNING:
@@ -272,30 +295,46 @@ class VizioDevice(MediaPlayerEntity):
     async def _async_update_options(self, config_entry: ConfigEntry) -> None:
         """Update options if the update signal comes from this entity."""
         self._volume_step = config_entry.options[CONF_VOLUME_STEP]
+        # Update so that CONF_ADDITIONAL_CONFIGS gets retained for imports
         self._conf_apps.update(config_entry.options.get(CONF_APPS, {}))
 
-    async def async_added_to_hass(self):
+    async def async_update_setting(
+        self, setting_type: str, setting_name: str, new_value: Union[int, str]
+    ) -> None:
+        """Update a setting when update_setting service is called."""
+        await self._device.set_setting(
+            setting_type,
+            setting_name,
+            new_value,
+        )
+
+    async def async_added_to_hass(self) -> None:
         """Register callbacks when entity is added."""
         # Register callback for when config entry is updated.
-        self._async_unsub_listeners.append(
+        self.async_on_remove(
             self._config_entry.add_update_listener(
                 self._async_send_update_options_signal
             )
         )
 
         # Register callback for update event
-        self._async_unsub_listeners.append(
+        self.async_on_remove(
             async_dispatcher_connect(
                 self.hass, self._config_entry.entry_id, self._async_update_options
             )
         )
 
-    async def async_will_remove_from_hass(self):
-        """Disconnect callbacks when entity is removed."""
-        for listener in self._async_unsub_listeners:
-            listener()
+        # Register callback for app list updates if device is a TV
+        @callback
+        def apps_list_update():
+            """Update list of all apps."""
+            self._all_apps = self._apps_coordinator.data
+            self.async_write_ha_state()
 
-        self._async_unsub_listeners.clear()
+        if self._device_class == DEVICE_CLASS_TV:
+            self.async_on_remove(
+                self._apps_coordinator.async_add_listener(apps_list_update)
+            )
 
     @property
     def available(self) -> bool:
@@ -303,7 +342,7 @@ class VizioDevice(MediaPlayerEntity):
         return self._available
 
     @property
-    def state(self) -> str:
+    def state(self) -> Optional[str]:
         """Return the state of the device."""
         return self._state
 
@@ -318,7 +357,7 @@ class VizioDevice(MediaPlayerEntity):
         return self._icon
 
     @property
-    def volume_level(self) -> float:
+    def volume_level(self) -> Optional[float]:
         """Return the volume level of the device."""
         return self._volume_level
 
@@ -328,7 +367,7 @@ class VizioDevice(MediaPlayerEntity):
         return self._is_volume_muted
 
     @property
-    def source(self) -> str:
+    def source(self) -> Optional[str]:
         """Return current input of the device."""
         if self._current_app is not None and self._current_input in INPUT_APPS:
             return self._current_app
@@ -455,7 +494,7 @@ class VizioDevice(MediaPlayerEntity):
                 )
             )
         elif source in self._available_apps:
-            await self._device.launch_app(source)
+            await self._device.launch_app(source, self._all_apps)
 
     async def async_volume_up(self) -> None:
         """Increase volume of the device."""
