@@ -19,8 +19,9 @@ from ..const import (
     SIGNAL_MOVE_LEVEL,
     SIGNAL_SET_LEVEL,
     SIGNAL_STATE_ATTR,
+    SIGNAL_UPDATE_DEVICE,
 )
-from .base import ZigbeeChannel, parse_and_log_command
+from .base import ClientChannel, ZigbeeChannel, parse_and_log_command
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -29,8 +30,6 @@ _LOGGER = logging.getLogger(__name__)
 class Alarms(ZigbeeChannel):
     """Alarms channel."""
 
-    pass
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.AnalogInput.cluster_id)
 class AnalogInput(ZigbeeChannel):
@@ -57,8 +56,6 @@ class AnalogValue(ZigbeeChannel):
 class ApplianceContorl(ZigbeeChannel):
     """Appliance Control channel."""
 
-    pass
-
 
 @registries.CHANNEL_ONLY_CLUSTERS.register(general.Basic.cluster_id)
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Basic.cluster_id)
@@ -129,29 +126,21 @@ class BinaryValue(ZigbeeChannel):
 class Commissioning(ZigbeeChannel):
     """Commissioning channel."""
 
-    pass
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.DeviceTemperature.cluster_id)
 class DeviceTemperature(ZigbeeChannel):
     """Device Temperature channel."""
 
-    pass
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.GreenPowerProxy.cluster_id)
 class GreenPowerProxy(ZigbeeChannel):
     """Green Power Proxy channel."""
 
-    pass
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Groups.cluster_id)
 class Groups(ZigbeeChannel):
     """Groups channel."""
 
-    pass
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Identify.cluster_id)
 class Identify(ZigbeeChannel):
@@ -166,8 +155,12 @@ class Identify(ZigbeeChannel):
             self.async_send_signal(f"{self.unique_id}_{cmd}", args[0])
 
 
+@registries.CLIENT_CHANNELS_REGISTRY.register(general.LevelControl.cluster_id)
+class LevelControlClientChannel(ClientChannel):
+    """LevelControl client cluster."""
+
+
 @registries.BINDABLE_CLUSTERS.register(general.LevelControl.cluster_id)
-@registries.EVENT_RELAY_CLUSTERS.register(general.LevelControl.cluster_id)
 @registries.LIGHT_CLUSTERS.register(general.LevelControl.cluster_id)
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.LevelControl.cluster_id)
 class LevelControlChannel(ZigbeeChannel):
@@ -233,9 +226,13 @@ class MultistateValue(ZigbeeChannel):
     REPORT_CONFIG = [{"attr": "present_value", "config": REPORT_CONFIG_DEFAULT}]
 
 
+@registries.CLIENT_CHANNELS_REGISTRY.register(general.OnOff.cluster_id)
+class OnOffClientChannel(ClientChannel):
+    """OnOff client channel."""
+
+
 @registries.BINARY_SENSOR_CLUSTERS.register(general.OnOff.cluster_id)
 @registries.BINDABLE_CLUSTERS.register(general.OnOff.cluster_id)
-@registries.EVENT_RELAY_CLUSTERS.register(general.OnOff.cluster_id)
 @registries.LIGHT_CLUSTERS.register(general.OnOff.cluster_id)
 @registries.SWITCH_CLUSTERS.register(general.OnOff.cluster_id)
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.OnOff.cluster_id)
@@ -318,22 +315,27 @@ class OnOffChannel(ZigbeeChannel):
 class OnOffConfiguration(ZigbeeChannel):
     """OnOff Configuration channel."""
 
-    pass
-
 
+@registries.CLIENT_CHANNELS_REGISTRY.register(general.Ota.cluster_id)
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Ota.cluster_id)
 class Ota(ZigbeeChannel):
     """OTA Channel."""
 
-    pass
+    @callback
+    def cluster_command(
+        self, tsn: int, command_id: int, args: Optional[List[Any]]
+    ) -> None:
+        """Handle OTA commands."""
+        cmd_name = self.cluster.server_commands.get(command_id, [command_id])[0]
+        signal_id = self._ch_pool.unique_id.split("-")[0]
+        if cmd_name == "query_next_image":
+            self.async_send_signal(SIGNAL_UPDATE_DEVICE.format(signal_id), args[3])
 
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Partition.cluster_id)
 class Partition(ZigbeeChannel):
     """Partition channel."""
 
-    pass
-
 
 @registries.CHANNEL_ONLY_CLUSTERS.register(general.PollControl.cluster_id)
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.PollControl.cluster_id)
@@ -427,26 +429,22 @@ class PowerConfigurationChannel(ZigbeeChannel):
 class PowerProfile(ZigbeeChannel):
     """Power Profile channel."""
 
-    pass
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.RSSILocation.cluster_id)
 class RSSILocation(ZigbeeChannel):
     """RSSI Location channel."""
 
-    pass
+
+@registries.CLIENT_CHANNELS_REGISTRY.register(general.Scenes.cluster_id)
+class ScenesClientChannel(ClientChannel):
+    """Scenes channel."""
 
 
-@registries.EVENT_RELAY_CLUSTERS.register(general.Scenes.cluster_id)
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Scenes.cluster_id)
 class Scenes(ZigbeeChannel):
     """Scenes channel."""
 
-    pass
-
 
 @registries.ZIGBEE_CHANNEL_REGISTRY.register(general.Time.cluster_id)
 class Time(ZigbeeChannel):
     """Time channel."""
-
-    pass
