@@ -3,7 +3,13 @@ import logging
 
 import zigpy.zcl.clusters.smartenergy as smartenergy
 
-from homeassistant.const import LENGTH_FEET, POWER_WATT, TIME_HOURS, TIME_SECONDS
+from homeassistant.const import (
+    POWER_WATT,
+    TIME_HOURS,
+    TIME_SECONDS,
+    VOLUME_CUBIC_FEET,
+    VOLUME_CUBIC_METERS,
+)
 from homeassistant.core import callback
 
 from .. import registries, typing as zha_typing
@@ -61,8 +67,8 @@ class Metering(ZigbeeChannel):
 
     unit_of_measure_map = {
         0x00: POWER_WATT,
-        0x01: f"m³/{TIME_HOURS}",
-        0x02: f"{LENGTH_FEET}³/{TIME_HOURS}",
+        0x01: f"{VOLUME_CUBIC_METERS}/{TIME_HOURS}",
+        0x02: f"{VOLUME_CUBIC_FEET}/{TIME_HOURS}",
         0x03: f"ccf/{TIME_HOURS}",
         0x04: f"US gal/{TIME_HOURS}",
         0x05: f"IMP gal/{TIME_HOURS}",
