@@ -410,13 +410,10 @@ class Light(BaseLight, ZhaEntity):
         if "effect" in last_state.attributes:
             self._effect = last_state.attributes["effect"]
 
-    async def async_update(self):
-        """Attempt to retrieve on off state from the light."""
-        await super().async_update()
-        await self.async_get_state()
-
     async def async_get_state(self, from_cache=True):
         """Attempt to retrieve on off state from the light."""
+        if not from_cache and not self.available:
+            return
         self.debug("polling current state - from cache: %s", from_cache)
         if self._on_off_channel:
             state = await self._on_off_channel.get_attribute_value(
