@@ -1,10 +1,8 @@
 """Typing Helpers for Home Assistant."""
-from typing import Any, Dict, Optional, Tuple
+from typing import Any, Dict, Mapping, Optional, Tuple, Union
 
 import homeassistant.core
 
-# pylint: disable=invalid-name
-
 GPSType = Tuple[float, float]
 ConfigType = Dict[str, Any]
 ContextType = homeassistant.core.Context
@@ -13,7 +11,8 @@ EventType = homeassistant.core.Event
 HomeAssistantType = homeassistant.core.HomeAssistant
 ServiceCallType = homeassistant.core.ServiceCall
 ServiceDataType = Dict[str, Any]
-TemplateVarsType = Optional[Dict[str, Any]]
+StateType = Union[None, str, int, float]
+TemplateVarsType = Optional[Mapping[str, Any]]
 
 # Custom type for recorder Queries
 QueryType = Any
